scxpand.data\_util.prepare\_data\_for\_train
============================================

.. automodule:: scxpand.data_util.prepare_data_for_train

   
   .. rubric:: Functions

   .. autosummary::
   
      prepare_data_for_training
   
   .. rubric:: Classes

   .. autosummary::
   
      TrainingDataBundle
   